"""
MySQL MCP Server

A Model Context Protocol (MCP) server for MySQL/MariaDB/TiDB/OceanBase databases.
"""

__version__ = "1.0.0"
__author__ = "Frank Jin"
__email__ = "j00131120@163.com"
__description__ = "A Model Context Protocol (MCP) server that enables secure interaction with MySQL/MariaDB/TiDB/AWS OceanBase/RDS/Aurora MySQL DataBases."

__all__ = [
    "__version__",
    "__author__",
    "__email__",
    "__description__",
]